@@ -20,16 +20,15 @@ made using urllib3. Assertions are made against the response.
 from collections import OrderedDict
 import copy
 import functools
+from http import cookies
 import os
 import re
 import sys
 import time
 import unittest
 from unittest import result as unitresult
+import urllib.parse as urlparse
 
-import six
-from six.moves import http_cookies
-from six.moves.urllib import parse as urlparse
 import wsgi_intercept
 
 from gabbi import __version__
@@ -78,7 +77,8 @@ BASE_TEST = {
     'skip': '',
     'poll': {},
     'use_prior_test': True,
-    'disable_response_handler': False
+    'disable_response_handler': False,
+    'timeout': 30,
 }
 
 
@@ -297,10 +297,10 @@ class HTTPTestCase(unittest.TestCase):
             referred_case = self.history[case]
         else:
             referred_case = self.prior
-        response_cookies = referred_case.response['set-cookie']
-        cookies = http_cookies.SimpleCookie()
-        cookies.load(response_cookies)
-        cookie_string = cookies.output(attrs=[], header='', sep=',').strip()
+        response_cookie = referred_case.response['set-cookie']
+        cookie = cookies.SimpleCookie()
+        cookie.load(response_cookie)
+        cookie_string = cookie.output(attrs=[], header='', sep=',').strip()
         return cookie_string
 
     def _headers_replace(self, message, escape_regex=False):
@@ -481,9 +481,17 @@ class HTTPTestCase(unittest.TestCase):
                 return self._cast_value(result, match.string)
             return result
         else:
-            return six.text_type(result)
+            return str(result)
 
-    def _run_request(self, url, method, headers, body, redirect=False):
+    def _run_request(
+        self,
+        url,
+        method,
+        headers,
+        body,
+        redirect=False,
+        timeout=30,
+    ):
         """Run the http request and decode output.
 
         The call to make the request will catch a WSGIAppError from
@@ -500,12 +508,13 @@ class HTTPTestCase(unittest.TestCase):
                 method=method,
                 headers=headers,
                 body=body,
-                redirect=redirect
+                redirect=redirect,
+                timeout=timeout,
             )
         except wsgi_intercept.WSGIAppError as exc:
             # Extract and re-raise the wrapped exception.
-            six.reraise(exc.exception_type, exc.exception_value,
-                        exc.traceback)
+            raise (exc.exception_type, exc.exception_value,
+                   exc.traceback)
 
         # Set headers and location attributes for follow on requests
         self.response = response
@@ -572,7 +581,7 @@ class HTTPTestCase(unittest.TestCase):
 
         # ensure body is bytes, encoding as UTF-8 because that's
         # what we do here
-        if isinstance(body, six.text_type):
+        if isinstance(body, str):
             body = body.encode('UTF-8')
 
         if test['poll']:
@@ -582,8 +591,14 @@ class HTTPTestCase(unittest.TestCase):
             failure = None
             while count:
                 try:
-                    self._run_request(full_url, method, headers, body,
-                                      redirect=test['redirects'])
+                    self._run_request(
+                        full_url,
+                        method,
+                        headers,
+                        body,
+                        redirect=test['redirects'],
+                        timeout=test['timeout'],
+                    )
                     self._assert_response()
                     failure = None
                     break
@@ -596,8 +611,14 @@ class HTTPTestCase(unittest.TestCase):
             if failure:
                 raise failure
         else:
-            self._run_request(full_url, method, headers, body,
-                              redirect=test['redirects'])
+            self._run_request(
+                full_url,
+                method,
+                headers,
+                body,
+                redirect=test['redirects'],
+                timeout=test['timeout'],
+            )
             self._assert_response()
 
     def _scheme_replace(self, message, escape_regex=False):
@@ -615,10 +636,10 @@ class HTTPTestCase(unittest.TestCase):
         """
         dumper_class = self.get_content_handler(content_type)
         if not _is_complex_type(data):
-            if isinstance(data, six.string_types) and data.startswith('<@'):
+            if isinstance(data, str) and data.startswith('<@'):
                 info = self.load_data_file(data.replace('<@', '', 1))
                 if utils.not_binary(content_type):
-                    data = six.text_type(info, 'UTF-8')
+                    data = str(info, 'UTF-8')
                 else:
                     # Return early we are binary content
                     return info
@@ -639,7 +660,7 @@ class HTTPTestCase(unittest.TestCase):
 
         # If the result after template handling is not a string, dump
         # it if there is a suitable dumper.
-        if dumper_class and not isinstance(data, six.string_types):
+        if dumper_class and not isinstance(data, str):
             # If there are errors dumping we want them to raise to the
             # test harness.
             data = dumper_class.dumps(data, test=self)
