@@ -11,13 +11,10 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from __future__ import print_function
-
 import os
 import sys
 
 import certifi
-import six
 import urllib3
 
 from gabbi.handlers import jsonhandler
@@ -35,13 +32,19 @@ class Http(urllib3.PoolManager):
     provided when it was used as the HTTP client.
     """
 
-    def request(self, absolute_uri, method, body, headers, redirect):
+    def request(self, absolute_uri, method, body, headers, redirect, timeout):
         if redirect:
             retry = urllib3.util.Retry(raise_on_redirect=False, redirect=5)
         else:
             retry = urllib3.util.Retry(total=False, redirect=False)
         response = super(Http, self).request(
-            method, absolute_uri, body=body, headers=headers, retries=retry)
+            method,
+            absolute_uri,
+            body=body,
+            headers=headers,
+            retries=retry,
+            timeout=timeout,
+        )
 
         # Transform response into something akin to httplib2
         # response object.
@@ -51,6 +54,10 @@ class Http(urllib3.PoolManager):
         headers = response.headers
         headers['status'] = str(status)
         headers['reason'] = reason
+
+        # Shut down open PoolManagers whose connections have completed to
+        # save on socket file descriptors.
+        self.clear()
         return headers, content
 
 
@@ -101,7 +108,7 @@ class VerboseHttp(Http):
             self.colorize = utils.get_colorizer(self._stream)
         super(VerboseHttp, self).__init__(**kwargs)
 
-    def request(self, absolute_uri, method, body, headers, redirect):
+    def request(self, absolute_uri, method, body, headers, redirect, timeout):
         """Display request parameters before requesting."""
 
         self._verbose_output('#### %s ####' % self.caption,
@@ -114,7 +121,7 @@ class VerboseHttp(Http):
         self._print_body(headers, body)
 
         response, content = super(VerboseHttp, self).request(
-            absolute_uri, method, body, headers, redirect)
+            absolute_uri, method, body, headers, redirect, timeout)
 
         # Blank line for division
         self._verbose_output('')
@@ -144,7 +151,7 @@ class VerboseHttp(Http):
         content_type = utils.extract_content_type(headers, 'text/plain')[0]
         if self._show_body and utils.not_binary(content_type):
             content = utils.decode_response_content(headers, content)
-            if isinstance(content, six.binary_type):
+            if isinstance(content, bytes):
                 content = content.decode('utf-8')
             # TODO(cdent): Using the JSONHandler here instead of
             # just the json module to make it clear that eventually
@@ -179,15 +186,37 @@ class VerboseHttp(Http):
         print(message, file=stream)
 
 
-def get_http(verbose=False, caption='', cert_validate=True):
+def get_http(
+    verbose=False,
+    caption='',
+    cert_validate=True,
+    hostname=None,
+    timeout=30,
+):
     """Return an ``Http`` class for making requests."""
     cert_validation = {'cert_reqs': 'CERT_NONE'} if not cert_validate else {}
 
     if not verbose:
-        return Http(strict=True, ca_certs=certifi.where(), **cert_validation)
+        return Http(
+            strict=True,
+            ca_certs=certifi.where(),
+            server_hostname=hostname,
+            timeout=timeout,
+            **cert_validation
+        )
 
     headers = False if verbose == 'body' else True
     body = False if verbose == 'headers' else True
-    return VerboseHttp(headers=headers, body=body, stream=sys.stdout,
-                       caption=caption, colorize=True, strict=True,
-                       ca_certs=certifi.where(), **cert_validation)
+
+    return VerboseHttp(
+        headers=headers,
+        body=body,
+        stream=sys.stdout,
+        caption=caption,
+        colorize=True,
+        strict=True,
+        ca_certs=certifi.where(),
+        server_hostname=hostname,
+        timeout=timeout,
+        **cert_validation
+    )
