@@ -27,7 +27,7 @@ from gabbi import httpclient
 from gabbi import suite
 
 
-class TestMaker(object):
+class TestMaker:
     """A class for encapsulating test invariants.
 
     All of the tests in a single gabbi file have invariants which are
@@ -80,9 +80,17 @@ class TestMaker(object):
         self._set_test_method_and_url(test, test_name)
         self._validate_keys(test, test_name)
 
+        # Set server hostname in http request if host header is set.
+        hostname = {
+            key.lower(): val for key, val in
+            test.get('request_headers', {}).items()
+        }.get('host', None)
+
         http_class = httpclient.get_http(verbose=test['verbose'],
                                          caption=test['name'],
-                                         cert_validate=test['cert_validate'])
+                                         cert_validate=test['cert_validate'],
+                                         hostname=hostname,
+                                         timeout=int(test["timeout"]))
         if prior_test:
             history = prior_test.history
         else:
