@@ -13,11 +13,11 @@
 """Test that the CLI works as expected
 """
 
+from io import StringIO
 import sys
 import unittest
 from uuid import uuid4
 
-from six import StringIO
 from wsgi_intercept.interceptor import Urllib3Interceptor
 
 from gabbi import exception
