@@ -15,8 +15,7 @@
 
 import copy
 import unittest
-
-from six.moves import mock
+from unittest import mock
 
 from gabbi import case
 
